==============
Administration
==============

The diagram plugin provides a graphical canvas for displaying diagrams.

The peek-plugin-diagram is a generic diagram display plugin,
that supports zooming, panning, touch, mobile, desktop,
and attribute updates from the peek-plugin-livedb plugin.

.. image:: example_diagram.png

.. toctree::
    :maxdepth: 3
    :caption: Contents:

    overview
    status/status
    admin_tasks
